CryptoError

Enum CryptoError 

pub enum CryptoError {
    UnsupportedVersion(u8),
    OldVersion(u8),
    DecryptFailed,
    BadLength {
        step: &'static str,
        actual: usize,
        expected: usize,
    },
    BadKey,
    BadFormat(&'static str),
    ObjectMismatch(&'static str),
    SignatureFailed,
    NotSupportedByVault,
}
Possible cryptographic submodule error conditions.

Variants



UnsupportedVersion(u8)

Crypto primitive uses a version this library doesn’t recognize (or one it no longer accepts).



OldVersion(u8)

Crypto primitive uses a version that’s too old, and deemed unsafe to use.



DecryptFailed

Crypto system was unable to decrypt the contents of a Lockbox.



BadLength

The provided data for wasn’t the expected length.

Fields

step: &'static str
actual: usize
expected: usize


BadKey

A provided cryptographic key (public or private) is weak or invalid.



BadFormat(&'static str)

The data format doesn’t match spec. Can occur when decoding a lockbox or attempting to decode from a String.



ObjectMismatch(&'static str)

An operation expected a specific object but didn’t get it. Eg. Signature verification expects a specific version of hash and fails if it doesn’t get a hash with that version, or a Lockbox should be unlocked with a specific key but we attempted to use the wrong one. This almost always indicates a logic error.



SignatureFailed

Verification of a signature failed.



NotSupportedByVault

The attempted operation isn’t supported by the backing Vault.

Implementations