pub struct DataLockboxRef(/* private fields */);Expand description
General encrypted data.
This must be decrypted by the matching recipient, which will return a Vec<u8> on success.
It can either be decrypted on its own or through a Vault. In both cases, the data is returned
without being stored anywhere.
This is only a reference to an encrypted payload. The owned version is DataLockbox.
See: StreamKey::decrypt_data,
LockKey::decrypt_data, and
Vault::decrypt_data.
Example
Using a StreamKey for decryption:
// We have `enc`, a byte vector containing a lockbox
let dec_lockbox: &DataLockboxRef = DataLockboxRef::from_bytes(&enc[..])?;
let recipient: LockboxRecipient = dec_lockbox.recipient();
// ...
// Retrieve the key by looking up recipient
// ...
let plaintext: Vec<u8> = key.decrypt_data(&dec_lockbox)?;Implementations
Sourceimpl DataLockboxRef
impl DataLockboxRef
Sourcepub fn as_parts(&self) -> LockboxParts<'_>
pub fn as_parts(&self) -> LockboxParts<'_>
Decompose the lockbox into its component parts.
Sourcepub fn recipient(&self) -> LockboxRecipient
pub fn recipient(&self) -> LockboxRecipient
Get the target recipient who can decrypt this.
pub fn from_bytes(buf: &[u8]) -> Result<&Self, CryptoError>